********************
Disclaimer
********************

The concept of packing belongs to `Impect <https://www.impect.com/>`__ and I do not take credit for the metric.

This is an attempt to create an open source variation of it, with few modifications on how the metrics are calculated. The logic
behind the metric calculations are explained here :ref:`in this section.<How packing is calculated?>`

For any questions/feedback, reach out to me on twitter `@SamiraK93 <https://twitter.com/Samirak93>`__.

If you'd like to file any issues/updates, submit a PR on `GitHub <https://github.com/samirak93/Football-packing>`__.